@@ -46,22 +46,6 @@ A total ordering exists on halfsegments, see the halfsegment comparison function
 '''
 
 
-def poiComp( L, R ):
-        '''
-        compare two points of the format (x,y)
-        
-        .. warning::
-
-          This function should not get used.  Tuple comparison does this automatically
-
-        **output**: true if L < R, false otherwise.
-        '''
-        x1 = L[0]
-        y1 = L[1]
-        x2 = R[0]
-        y2 = R[1]
-        return x1 < x2 or ( x1 == x2 and y1 < y2 )
-
 
 def isLeft( hseg ):
         '''
@@ -69,12 +53,12 @@ def isLeft( hseg ):
 
         A halfsegment has the structure: (((x1,y1),(x2,y2)),la,lb) where la,lb are ints
         '''
-        return poiComp( hseg[0][0], hseg[0][1] )
+        return hseg[0][0]< hseg[0][1]
 
 
 def collinear( L, R ):
         '''
-        returns true if L and R are EXACTLY colinear.  Check the colinearity functions in segLibrary if a tolerance is allowed.
+        returns true if L and R are EXACTLY collinear.  Check the collinearity functions in segLibrary if a tolerance is allowed.
         '''
         x1 = L[0][0][0]
         y1 = L[0][0][1]
@@ -112,7 +96,7 @@ def hsegComp( L, R ):
 
         **output**: True if L < R, False otherwise
         '''
-        if poiComp( L[0][0], R[0][0] ):
+        if L[0][0]< R[0][0]:
                 return True;
         elif L[0][0] == R[0][0]:
                 if not isLeft(L) and isLeft(R):
@@ -790,7 +774,7 @@ def isLeftTurn( p1,p2,p3):
 
         **input**: 3 points, p1, p2, p3 in (x,y) format
 
-        **output**: -1 if its a left turn, 0 if the points ar colinear, 1 if its a right turn.
+        **output**: -1 if its a left turn, 0 if the points ar collinear, 1 if its a right turn.
         '''
         p1x = p1[0]
         p1y = p1[1]
