@@ -22,6 +22,7 @@
 
 
 from pyspatiotemporalgeom.utilities import hsegLibrary
+from pyspatiotemporalgeom.utilities import segLibrary
 import math
 import collections
 from pyspatiotemporalgeom.utilities import convexHull
@@ -207,79 +208,6 @@ def appendToAnimationFile( triList, fileObject, numFrames = 100 ):
                 numer+=1
                 fileObject.write('\n')
         
-
-def isColinearAndOverlapping( Lseg, Rseg, tolerance = .000001 ):
-        '''
-        check if two segments are colinear within a tolerance and overlapping
-
-        Input:
-        
-        Lseg and Rseg: two line segments
-
-        Tolerance: A tolerance value for colinearity
-
-        Returns:
-
-          ``True`` if the segments are colinear within tolerance AND overlapping
-
-          ``False`` otherwise
-        '''
-
-        L = (Lseg[0], Lseg[1])
-        R = (Rseg[0], Rseg[1])
-        
-        if L == None or R == None:
-                return False
-        if L == R or L == (R[1], R[0]):
-                return True
-        negt = tolerance * -1
-        # will be colinear if l1,l2,r1 and l1,l2,r2 are all within tolerance
-        v1 = colinearValue( L[0], L[1], R[0])
-        v2 = colinearValue( L[0], L[1], R[1])
-        if negt <= v1 and v1 <= tolerance and negt <= v2 and v2 <= tolerance:
-                # lines are colinear. values to compare
-                ll = L[0][0]
-                lu = L[1][0]
-                rl = R[0][0]
-                ru = R[1][0]
-                if ll == lu: #vertical lines
-                        ll = L[0][1]
-                        lu = L[1][1]
-                        rl = R[0][1]
-                        ru = R[1][1]
-                if lu < ll:
-                        tmp = ll
-                        ll = lu
-                        lu = tmp
-                if ru < rl:
-                        tmp = rl
-                        rl = ru
-                        ru = tmp
-                # if one value from R is between the values from L, they are colinear and overlapping
-                # eqivalent segs are checked way at the top
-                if ((ll < rl and rl < lu) or ( ll < ru and ru < lu)) or  ((rl < ll and ll < ru) or ( rl < lu and lu < ru)):
-                        return True
-        return False
-
-def colinearValue( p1,p2,p3):
-        '''
-
-        p1,p2, and p3 are points: (x,y)
-
-        will return a 0 if p1, p2,p3 are exactly colinear
-        
-        will return positive value if it forms a left turn
-        
-        will return neg value if it forms a right turn
-        
-        '''
-        p1x = p1[0]
-        p1y = p1[1]
-        p2x = p2[0]
-        p2y = p2[1]
-        p3x = p3[0]
-        p3y = p3[1]
-        return  ((p3y - p1y) * (p2x - p1x)) - ((p2y - p1y) * (p3x - p1x))
         
         
 def writeHsegsToTextFile( fileName, hsegs ):
@@ -442,11 +370,11 @@ def interpolate(r1,r2, startTime, endTime, noTriIntersectionChecks = False ):
                 midX = (midX + t[2][0]) /2.0
                 midY = (midY + t[2][1]) /2.0
                 p = (midX, midY)
-                validAtBoundary =  (r1ConcHullSeg[t[3]]!= None and isColinearAndOverlapping( (t[0], t[1]), r1ConcHullSeg[t[3]] )) or (t[0],t[1]) in r1ConnectorSegSet or (t[1],t[0]) in r1ConnectorSegSet
+                validAtBoundary =  (r1ConcHullSeg[t[3]]!= None and segLibrary.isCollinearAndOverlapping( (t[0], t[1]), r1ConcHullSeg[t[3]] )) or (t[0],t[1]) in r1ConnectorSegSet or (t[1],t[0]) in r1ConnectorSegSet
                 evapMotionSegs.append( (t[0]+(splitTime1,), t[1]+(splitTime1,), p+(startTime,), validAtBoundary) )
-                validAtBoundary =  (r1ConcHullSeg[t[3]]!= None and isColinearAndOverlapping( (t[0], t[2]), r1ConcHullSeg[t[3]] )) or (t[0],t[2]) in r1ConnectorSegSet or (t[2],t[0]) in r1ConnectorSegSet
+                validAtBoundary =  (r1ConcHullSeg[t[3]]!= None and segLibrary.isCollinearAndOverlapping( (t[0], t[2]), r1ConcHullSeg[t[3]] )) or (t[0],t[2]) in r1ConnectorSegSet or (t[2],t[0]) in r1ConnectorSegSet
                 evapMotionSegs.append( (t[0]+(splitTime1,), t[2]+(splitTime1,), p+(startTime,), validAtBoundary) )
-                validAtBoundary =  (r1ConcHullSeg[t[3]]!= None and isColinearAndOverlapping( (t[1], t[2]), r1ConcHullSeg[t[3]] )) or (t[1],t[2]) in r1ConnectorSegSet or (t[2],t[1]) in r1ConnectorSegSet
+                validAtBoundary =  (r1ConcHullSeg[t[3]]!= None and segLibrary.isCollinearAndOverlapping( (t[1], t[2]), r1ConcHullSeg[t[3]] )) or (t[1],t[2]) in r1ConnectorSegSet or (t[2],t[1]) in r1ConnectorSegSet
                 evapMotionSegs.append( (t[1]+(splitTime1,), t[2]+(splitTime1,), p+(startTime,), validAtBoundary) )
         
         # repeat for condense segs
@@ -478,11 +406,11 @@ def interpolate(r1,r2, startTime, endTime, noTriIntersectionChecks = False ):
                 midX = (midX + t[2][0]) /2.0
                 midY = (midY + t[2][1]) /2.0
                 p = (midX, midY)
-                validAtBoundary = (r2ConcHullSeg[t[3]]!= None and isColinearAndOverlapping( (t[0], t[1]), r2ConcHullSeg[t[3]] )) or (t[0],t[1]) in r2ConnectorSegSet or (t[1],t[0]) in r2ConnectorSegSet
+                validAtBoundary = (r2ConcHullSeg[t[3]]!= None and segLibrary.isCollinearAndOverlapping( (t[0], t[1]), r2ConcHullSeg[t[3]] )) or (t[0],t[1]) in r2ConnectorSegSet or (t[1],t[0]) in r2ConnectorSegSet
                 condMotionSegs.append( (t[0]+(splitTime2,), t[1]+(splitTime2,), p+(endTime,), validAtBoundary) )
-                validAtBoundary =  (r2ConcHullSeg[t[3]]!= None and isColinearAndOverlapping( (t[0], t[2]), r2ConcHullSeg[t[3]] )) or (t[0],t[2]) in r2ConnectorSegSet or (t[2],t[0]) in r2ConnectorSegSet
+                validAtBoundary =  (r2ConcHullSeg[t[3]]!= None and segLibrary.isCollinearAndOverlapping( (t[0], t[2]), r2ConcHullSeg[t[3]] )) or (t[0],t[2]) in r2ConnectorSegSet or (t[2],t[0]) in r2ConnectorSegSet
                 condMotionSegs.append( (t[0]+(splitTime2,), t[2]+(splitTime2,), p+(endTime,), validAtBoundary) )
-                validAtBoundary =  (r2ConcHullSeg[t[3]]!= None and isColinearAndOverlapping( (t[1], t[2]), r2ConcHullSeg[t[3]] )) or (t[1],t[2]) in r2ConnectorSegSet or (t[2],t[1]) in r2ConnectorSegSet
+                validAtBoundary =  (r2ConcHullSeg[t[3]]!= None and segLibrary.isCollinearAndOverlapping( (t[1], t[2]), r2ConcHullSeg[t[3]] )) or (t[1],t[2]) in r2ConnectorSegSet or (t[2],t[1]) in r2ConnectorSegSet
                 condMotionSegs.append( (t[1]+(splitTime2,), t[2]+(splitTime2,), p+(endTime,), validAtBoundary) )
         
         # create intermediate regions.  remove segs from offending concs, add in the hullseg
