@@ -18,6 +18,7 @@
 #    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 #    THE SOFTWARE.
 
+
 import math
 from pyspatiotemporalgeom.utilities import segLibrary
 
@@ -112,9 +113,9 @@ def verticalSegment3DAndTriangle3DIntersection( ray, tri):
   * (triangles always have points [0] and [1] from the same slice. In other words, for the representation listed above, z1 = z2 ALWAYS.)
   * ray: a line segment of the form ((x1,y1,z1),(x2,y2,z2)) that is vertical in the Z dimension and that spans the Z dimension of the triangle
 
-  Output:
+  Returns:
 
-  * a list containing 0, 1, or 2 points: ((x,y,z),(x2,y2,z2)) or ((x,y,z)).  The ray may graze the triangle at a point or along a segment, it may enter and then leave a co-planar triangle, or it may miss the triangle.
+  * a list containing 0, 1, or 2 3D points: [],  [((x,y,z),(x2,y2,z2))] or [((x,y,z))].  The segment may graze the triangle at a point or along a segment, it may enter and then leave a co-planar triangle, or it may miss the triangle.
 
   '''
   
@@ -207,8 +208,8 @@ def verticalSegment3DAndTriangle3DIntersection( ray, tri):
         exit()
     resultList = [ resTuple[1] ]
     return resultList
-  print 'Should not reach this code in segment3dtriangle3dintersection()'
-  exit()
+  # if we get here, there was no intersection!
+  return []
   
  
 
@@ -218,6 +219,7 @@ def verticalSegment3DAndSegment3DIntersection( verticalSegProjectedTo2D, seg3D )
   is no intersection, a ``None`` value is returned.
 
   Input:
+
   * verticalSegProjectedTo2D: a point tuple ``(x,y)`` defining a vertical line in 3D
   * seg3D: a 3d line segment tuple: ``((x1,y1,z1),(x2,y2,z2))``
 
@@ -279,9 +281,9 @@ def verticalSegment3DAndSegment3DIntersection( verticalSegProjectedTo2D, seg3D )
 def segment3DTriangle3DIntersection( seg, tri ):
         '''
         
-        Test if a triangle and a ray intersect.  A ray is actually a seg in our case. 
-        
-        To conver this algorithm to use rays, change the line:
+        Test if a triangle and a 3D segment intersect. Whereas some of the other functions assume a vertical segment in the Z dimension, this function assumes NO orientation of the segment.  It can be pointing in any direction.
+
+        To convert this algorithm to use rays, change the line:
             
         ``if r <= 0.0 or r >= 1.0:``
         
@@ -289,11 +291,12 @@ def segment3DTriangle3DIntersection( seg, tri ):
         
         ``if r <= 0.0:``
 
-        We will always pass segs, since triangles will end at slice boundaries
+        **Input:** 
         
-        tri is a triangle a tuple of 3, 3D points.  Triangle vertices in arbitrary order
+        + ``seg`` is a lien segment of the usual format ((x1,y1),(x2,y2))
+        + ``tri`` is a triangle a tuple of 3, 3D points.  Triangle vertices in arbitrary order
         
-        **Returns** a tuple containing a value indicating the type of intersection, and the actual intersection point (if it exists, ``None`` otherwise):
+        **Returns:** a tuple containing a value indicating the type of intersection, and the actual intersection point (if it exists, ``None`` otherwise):
         
         ``(value, point)`` where ``value`` is:
 
